==> QupZilla-2.2.3.tar.xz: QupZilla-2.2.3/src/plugins/GreaseMonkey/translations/bg_BG.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg_BG" version="2.1">
<context>
    <name>GM_AddScriptDialog</name>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="14"/>
        <source>GreaseMonkey Installation</source>
        <translation>Инсталиране на GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="45"/>
        <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Инсталиране на GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="67"/>
        <source>You are about to install this userscript into GreaseMonkey:</source>
        <translation>На път сте да инсталирате този потребителски скрипт в GreaseMonkey:</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="80"/>
        <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Трябва да инсталирате скриптове само от източници, на които имате доверие!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="90"/>
        <source>Are you sure you want to install it?</source>
        <translation>Сигурни ли сте, че искате да го инсталирате?</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="108"/>
        <source>Show source code of script</source>
        <translation>Преглед на изходния код на скрипта</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="50"/>
        <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;работи на&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="54"/>
        <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;не работи на&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="84"/>
        <source>Cannot install script</source>
        <translation>Скриптът не може да се инсталира</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="87"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; е успешно инсталиран</translation>
    </message>
</context>
<context>
    <name>GM_Icon</name>
    <message>
        <location filename="../gm_icon.cpp" line="29"/>
        <source>Open GreaseMonkey settings</source>
        <translation>Отваряне настройките на GreaseMonkey</translation>
    </message>
</context>
<context>
    <name>GM_Manager</name>
    <message>
        <location filename="../gm_manager.cpp" line="203"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_manager.cpp" line="267"/>
        <source>&apos;%1&apos; is already installed</source>
        <translation>&apos;%1&apos; вече е инсталиран</translation>
    </message>
</context>
<context>
    <name>GM_Notification</name>
    <message>
        <location filename="../gm_notification.ui" line="39"/>
        <source>This script can be installed with the GreaseMonkey plugin.</source>
        <translation>Този скрипт може да бъде инсталиран с приставката Greasemonkey.</translation>
    </message>
    <message>
        <location filename="../gm_notification.ui" line="59"/>
        <source>Install</source>
        <translation>Инсталиране</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="51"/>
        <source>Cannot install script</source>
        <translation>Скриптът не може да се инсталира</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="59"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; е успешно инсталиран</translation>
    </message>
</context>
<context>
    <name>GM_Settings</name>
    <message>
        <location filename="../settings/gm_settings.ui" line="14"/>
        <source>GreaseMonkey Scripts</source>
        <translation>GreaseMonkey скриптове</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="48"/>
        <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;GreaseMonkey скриптове&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="70"/>
        <source>Double clicking script will show additional information</source>
        <translation>Двойно кликване върху скрипта ще покаже допълнителна информация</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="150"/>
        <source>More scripts can be downloaded from</source>
        <translation>Още скриптове могат да бъдат свалени от</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="193"/>
        <source>Open scripts directory</source>
        <translation>Отваряне на папката със скриптове</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="200"/>
        <source>New user script</source>
        <translation>Нов потребителски скрипт</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="91"/>
        <source>Remove script</source>
        <translation>Премахване на скрипта</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="92"/>
        <source>Are you sure you want to remove &apos;%1&apos;?</source>
        <translation>Сигурни ли сте, че искате да премахнете &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="122"/>
        <source>Add script</source>
        <translation>Добавяне на скрипт</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="122"/>
        <source>Choose name for script:</source>
        <translation>Избор на име за скрипта:</translation>
    </message>
</context>
<context>
    <name>GM_SettingsScriptInfo</name>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="85"/>
        <source>Name:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="55"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="115"/>
        <source>URL:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="138"/>
        <source>Namespace:</source>
        <translation>Местоположение:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="155"/>
        <source>Edit in text editor</source>
        <translation>Редактиране в текстов редактор</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="65"/>
        <source>Start at:</source>
        <translation>Започва с:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="45"/>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="19"/>
        <source>Runs at:</source>
        <translation>Работи на:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="128"/>
        <source>Does not run at:</source>
        <translation>Не работи на:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.cpp" line="45"/>
        <source>Script Details of %1</source>
        <translation>Подробна информация за скрипт %1</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.5.tar.xz: QupZilla-2.2.5/src/plugins/GreaseMonkey/translations/bg_BG.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg_BG" version="2.1">
<context>
    <name>GM_AddScriptDialog</name>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="14"/>
        <source>GreaseMonkey Installation</source>
        <translation>Инсталиране на GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="45"/>
        <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Инсталиране на GreaseMonkey&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="67"/>
        <source>You are about to install this userscript into GreaseMonkey:</source>
        <translation>На път сте да инсталирате този потребителски скрипт в GreaseMonkey:</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="80"/>
        <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Трябва да инсталирате скриптове само от източници, на които имате доверие!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="90"/>
        <source>Are you sure you want to install it?</source>
        <translation>Сигурни ли сте, че искате да го инсталирате?</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="108"/>
        <source>Show source code of script</source>
        <translation>Преглед на изходния код на скрипта</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="50"/>
        <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;работи на&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="54"/>
        <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;не работи на&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="84"/>
        <source>Cannot install script</source>
        <translation>Скриптът не може да се инсталира</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="87"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; е успешно инсталиран</translation>
    </message>
</context>
<context>
    <name>GM_Icon</name>
    <message>
        <location filename="../gm_icon.cpp" line="29"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_icon.cpp" line="30"/>
        <source>Open GreaseMonkey settings</source>
        <translation>Отваряне настройките на GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_icon.cpp" line="42"/>
        <source>GreaseMonkey Icon</source>
        <translation>GreaseMonkey икона</translation>
    </message>
</context>
<context>
    <name>GM_Manager</name>
    <message>
        <location filename="../gm_manager.cpp" line="211"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
    <message>
        <location filename="../gm_manager.cpp" line="278"/>
        <source>&apos;%1&apos; is already installed</source>
        <translation>&apos;%1&apos; вече е инсталиран</translation>
    </message>
</context>
<context>
    <name>GM_Notification</name>
    <message>
        <location filename="../gm_notification.ui" line="39"/>
        <source>This script can be installed with the GreaseMonkey plugin.</source>
        <translation>Този скрипт може да бъде инсталиран с приставката Greasemonkey.</translation>
    </message>
    <message>
        <location filename="../gm_notification.ui" line="59"/>
        <source>Install</source>
        <translation>Инсталиране</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="51"/>
        <source>Cannot install script</source>
        <translation>Скриптът не може да се инсталира</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="59"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos; е успешно инсталиран</translation>
    </message>
</context>
<context>
    <name>GM_Settings</name>
    <message>
        <location filename="../settings/gm_settings.ui" line="14"/>
        <source>GreaseMonkey Scripts</source>
        <translation>GreaseMonkey скриптове</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="48"/>
        <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;GreaseMonkey скриптове&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="70"/>
        <source>Double clicking script will show additional information</source>
        <translation>Двойно кликване върху скрипта ще покаже допълнителна информация</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="150"/>
        <source>More scripts can be downloaded from</source>
        <translation>Още скриптове могат да бъдат свалени от</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="193"/>
        <source>Open scripts directory</source>
        <translation>Отваряне на папката със скриптове</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="200"/>
        <source>New user script</source>
        <translation>Нов потребителски скрипт</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="91"/>
        <source>Remove script</source>
        <translation>Премахване на скрипта</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="92"/>
        <source>Are you sure you want to remove &apos;%1&apos;?</source>
        <translation>Сигурни ли сте, че искате да премахнете &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="122"/>
        <source>Add script</source>
        <translation>Добавяне на скрипт</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="122"/>
        <source>Choose name for script:</source>
        <translation>Избор на име за скрипта:</translation>
    </message>
</context>
<context>
    <name>GM_SettingsScriptInfo</name>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="85"/>
        <source>Name:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="55"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="115"/>
        <source>URL:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="138"/>
        <source>Namespace:</source>
        <translation>Местоположение:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="155"/>
        <source>Edit in text editor</source>
        <translation>Редактиране в текстов редактор</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="65"/>
        <source>Start at:</source>
        <translation>Започва с:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="45"/>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="19"/>
        <source>Runs at:</source>
        <translation>Работи на:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="128"/>
        <source>Does not run at:</source>
        <translation>Не работи на:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.cpp" line="45"/>
        <source>Script Details of %1</source>
        <translation>Подробна информация за скрипт %1</translation>
    </message>
</context>
</TS>
